MarkdownLanguage

Struct MarkdownLanguage 

pub struct MarkdownLanguage {
Show 22 fields pub allow_math: bool, pub allow_tables: bool, pub allow_task_lists: bool, pub allow_strikethrough: bool, pub allow_footnotes: bool, pub allow_front_matter: bool, pub allow_definition_lists: bool, pub allow_subscript: bool, pub allow_autolinks: bool, pub allow_abbreviations: bool, pub allow_indented_code_blocks: bool, pub allow_html: bool, pub allow_hard_line_breaks: bool, pub allow_gfm_autolinks: bool, pub allow_headings: bool, pub allow_lists: bool, pub allow_blockquotes: bool, pub allow_fenced_code_blocks: bool, pub allow_horizontal_rules: bool, pub allow_setext_headings: bool, pub allow_html_tagfilter: bool, pub allow_xml: bool,
}
Configuration for the Markdown language features.

Fields

allow_math: bool

Enable math formulas.

Example: $a^2 + b^2 = c^2$ or $$E = mc^2$$

allow_tables: bool

Enable tables.

Example:

Header
Cell
allow_task_lists: bool

Enable task lists.

Example: - [ ] Task or - [x] Done

allow_strikethrough: bool

Enable strikethrough.

Example: ~~deleted~~

allow_footnotes: bool

Enable footnotes.

Example: [^1] and [^1]: Note

allow_front_matter: bool

Enable front matter (YAML/TOML/JSON).

Example:

title: Hello

allow_definition_lists: bool

Enable definition lists.

Example: Term : Definition

allow_subscript: bool

Enable superscript and subscript.

Example: ^sup^ or ~sub~

allow_autolinks: bool

Enable autolinks.

Example: <https://example.com>

allow_abbreviations: bool

Enable abbreviations.

Example: *[HTML]: HyperText Markup Language

allow_indented_code_blocks: bool

Enable indented code blocks.

Example: code block

allow_html: bool

Enable inline HTML tags.

Example: <div> or <!-- comment -->

allow_hard_line_breaks: bool

Enable hard line breaks.

Example: Two spaces at the end of a line or a backslash.

allow_gfm_autolinks: bool

Enable GFM-style autolinks.

Example: https://example.com

allow_headings: bool

Enable ATX headings.

Example: # Heading

allow_lists: bool

Enable lists.

Example: - Item or 1. Item

allow_blockquotes: bool

Enable blockquotes.

Example: > Quote

allow_fenced_code_blocks: bool

Enable fenced code blocks.

Example: ```rust

allow_horizontal_rules: bool

Enable horizontal rules.

Example: --- or ***

allow_setext_headings: bool

Enable Setext headings.

Example: Heading

allow_html_tagfilter: bool

Enable GFM Tagfilter.

Filters certain HTML tags like <script>.

allow_xml: bool

Enable XML/TSX syntax.

Example: <Component />

Implementations

Source

impl MarkdownLanguage

pub fn new() -> Self

Creates a new Markdown language configuration with default settings.