MarkdownTokenType

Enum MarkdownTokenType 

pub enum MarkdownTokenType {
Show 82 variants Text, Whitespace, Newline, Heading1, Heading2, Heading3, Heading4, Heading5, Heading6, HeadingText, Emphasis, Strong, Strikethrough, InlineCode, CodeBlock, CodeFence, CodeLanguage, Link, LinkText, LinkUrl, LinkTitle, Image, ImageAlt, ImageUrl, ImageTitle, Blockquote, BlockquoteMarker, List, ListItem, ListMarker, UnorderedList, OrderedList, TaskList, TaskMarker, Table, TableRow, TableCell, TableHeader, TableSeparator, TableAlignment, HorizontalRule, MathInline, MathBlock, FrontMatter, FootnoteDefinition, FootnoteReference, DefinitionList, DefinitionTerm, DefinitionDescription, Superscript, Subscript, Abbreviation, HtmlTag, HtmlComment, XmlTag, XmlComment, Asterisk, Underscore, Backtick, Tilde, Hash, Less, Greater, LBracket, RBracket, LParen, RParen, Exclamation, Pipe, Dash, Plus, Dot, Colon, Dollar, Caret, Escape, Error, Root, Document, Paragraph, AutoLink, EndOfStream,
}
Token types for the Markdown language.

Variants



Text

Plain text.



Whitespace

Whitespace characters.



Newline

A newline character.



Heading1

Heading level 1: #.



Heading2

Heading level 2: ##.



Heading3

Heading level 3: ###.



Heading4

Heading level 4: ####.



Heading5

Heading level 5: #####.



Heading6

Heading level 6: ######.



HeadingText

The text content of a heading.



Emphasis

Emphasized text: * or _.



Strong

Strong text: ** or __.



Strikethrough

Strikethrough text: ~~.



InlineCode

Inline code: `.



CodeBlock

A code block.



CodeFence

A code fence: ``` or ~~~.



CodeLanguage

The language identifier for a code block.

A link.



LinkText

The text of a link.



LinkUrl

The URL of a link.



LinkTitle

The title of a link.



Image

An image.



ImageAlt

The alt text of an image.



ImageUrl

The URL of an image.



ImageTitle

The title of an image.



Blockquote

A blockquote.



BlockquoteMarker

The marker for a blockquote: >.



List

A list.



ListItem

An item in a list.



ListMarker

The marker for a list item: -, *, +, or 1..



UnorderedList

An unordered list.



OrderedList

An ordered list.



TaskList

A task list.



TaskMarker

The marker for a task: [ ] or [x].



Table

A table.



TableRow

A row in a table.



TableCell

A cell in a table.



TableHeader

A table header cell.



TableSeparator

A table separator row.



TableAlignment

Table column alignment.



HorizontalRule

A horizontal rule: ---, ***, or ___.



MathInline

Inline math: $.



MathBlock

Block math: $$.



FrontMatter

Front matter: ---.



FootnoteDefinition

A footnote definition.



FootnoteReference

A footnote reference.



DefinitionList

A definition list.



DefinitionTerm

A term in a definition list.



DefinitionDescription

A description in a definition list.



Superscript

Superscript text.



Subscript

Subscript text.



Abbreviation

An abbreviation.



HtmlTag

An HTML tag.



HtmlComment

An HTML comment.



XmlTag

An XML tag.



XmlComment

An XML comment.



Asterisk

An asterisk: *.



Underscore

An underscore: _.



Backtick

A backtick: `.



Tilde

A tilde: ~.



Hash

A hash sign: #.



Less

A less than sign: <.



Greater

A greater than sign: >.



LBracket

A left bracket: [.



RBracket

A right bracket: ].



LParen

A left parenthesis: (.



RParen

A right parenthesis: ).



Exclamation

An exclamation mark: !.



Pipe

A pipe symbol: |.



Dash

A dash: -.



Plus

A plus sign: +.



Dot

A dot: ..



Colon

A colon: :.



Dollar

A dollar sign: $.



Caret

A caret symbol: ^.



Escape

An escape character: \.



Error

An error token.



Root

The root node of a Markdown document.



Document

A Markdown document.



Paragraph

A paragraph of text.

An automatic link (HTTP/HTTPS URL).



EndOfStream

End of stream.