pub struct MarkdownLanguage {
pub allow_math: bool,
}Fields
allow_math: boolTrait Implementations
Sourceimpl<'config> Builder<MarkdownLanguage> for MarkdownBuilder<'config>
impl<'config> Builder<MarkdownLanguage> for MarkdownBuilder<'config>
Sourcefn build<'a, S: Source + ?Sized>(
&self,
source: &S,
edits: &[TextEdit],
_cache: &'a mut impl BuilderCache<MarkdownLanguage>,
) -> BuildOutput<MarkdownLanguage>
fn build<'a, S: Source + ?Sized>( &self, source: &S, edits: &[TextEdit], _cache: &'a mut impl BuilderCache<MarkdownLanguage>, ) -> BuildOutput<MarkdownLanguage>
Builds the structure from the source text.
Sourceimpl Clone for MarkdownLanguage
impl Clone for MarkdownLanguage
Sourcefn clone(&self) -> MarkdownLanguage
fn clone(&self) -> MarkdownLanguage
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MarkdownLanguage
impl Debug for MarkdownLanguage
Sourceimpl Default for MarkdownLanguage
impl Default for MarkdownLanguage
Sourceimpl<'de> Deserialize<'de> for MarkdownLanguage
impl<'de> Deserialize<'de> for MarkdownLanguage
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for MarkdownLanguage
impl Hash for MarkdownLanguage
Sourceimpl Language for MarkdownLanguage
impl Language for MarkdownLanguage
Sourceconst CATEGORY: LanguageCategory = LanguageCategory::Markup
const CATEGORY: LanguageCategory = LanguageCategory::Markup
The category of the language.
Sourcetype TokenType = MarkdownSyntaxKind
type TokenType = MarkdownSyntaxKind
The token type used to represent different token and node types in the language. Read more
Sourcetype ElementType = MarkdownSyntaxKind
type ElementType = MarkdownSyntaxKind
The element type used to represent composite structures in the parsed tree. Read more
Sourcetype TypedRoot = MarkdownRoot
type TypedRoot = MarkdownRoot
The root type for the parsed tree that represents the top-level structure of the language. Read more
Sourceimpl<'config> Lexer<MarkdownLanguage> for MarkdownLexer<'config>
impl<'config> Lexer<MarkdownLanguage> for MarkdownLexer<'config>
Sourcefn lex<'a, S: Source + ?Sized>(
&self,
text: &'a S,
_edits: &[TextEdit],
cache: &'a mut impl LexerCache<MarkdownLanguage>,
) -> LexOutput<MarkdownLanguage>
fn lex<'a, S: Source + ?Sized>( &self, text: &'a S, _edits: &[TextEdit], cache: &'a mut impl LexerCache<MarkdownLanguage>, ) -> LexOutput<MarkdownLanguage>
Tokenizes the given source text into a sequence of tokens. Read more
Sourceimpl<'config> Parser<MarkdownLanguage> for MarkdownParser<'config>
impl<'config> Parser<MarkdownLanguage> for MarkdownParser<'config>
Sourcefn parse<'a, S: Source + ?Sized>(
&self,
text: &'a S,
edits: &[TextEdit],
cache: &'a mut impl ParseCache<MarkdownLanguage>,
) -> ParseOutput<'a, MarkdownLanguage>
fn parse<'a, S: Source + ?Sized>( &self, text: &'a S, edits: &[TextEdit], cache: &'a mut impl ParseCache<MarkdownLanguage>, ) -> ParseOutput<'a, MarkdownLanguage>
The core parsing entry point. Read more
Sourceimpl PartialEq for MarkdownLanguage
impl PartialEq for MarkdownLanguage
Sourceimpl Serialize for MarkdownLanguage
impl Serialize for MarkdownLanguage
impl Copy for MarkdownLanguage
impl Eq for MarkdownLanguage
impl StructuralPartialEq for MarkdownLanguage