pub struct MarkdownLanguage {
pub allow_math: bool,
}Fields
allow_math: boolTrait Implementations
Sourceimpl Debug for MarkdownLanguage
impl Debug for MarkdownLanguage
Sourceimpl Default for MarkdownLanguage
impl Default for MarkdownLanguage
Sourceimpl Language for MarkdownLanguage
impl Language for MarkdownLanguage
Sourcetype SyntaxKind = MarkdownSyntaxKind
type SyntaxKind = MarkdownSyntaxKind
The kind kind type used to represent different kind and node types in the language. Read more
Sourceimpl<'config> Lexer<MarkdownLanguage> for MarkdownLexer<'config>
impl<'config> Lexer<MarkdownLanguage> for MarkdownLexer<'config>
Sourcefn lex_incremental(
&self,
source: impl Source,
changed: usize,
cache: IncrementalCache<'_, MarkdownLanguage>,
) -> LexOutput<MarkdownLanguage>
fn lex_incremental( &self, source: impl Source, changed: usize, cache: IncrementalCache<'_, MarkdownLanguage>, ) -> LexOutput<MarkdownLanguage>
Tokenizes source text using an existing cache for incremental parsing. Read more
Sourcefn lex(
&self,
source: impl Source,
) -> OakDiagnostics<Vec<Token<<L as Language>::SyntaxKind>>>
fn lex( &self, source: impl Source, ) -> OakDiagnostics<Vec<Token<<L as Language>::SyntaxKind>>>
Tokenizes the given source text into a sequence of tokens. Read more